use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.17

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Dist/Zilla/Plugin/OptionalFeature.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/01-basic.t',
    't/02-no-configure.t',
    't/03-name-syntax.t',
    't/04-default.t',
    't/05-require-develop.t',
    't/06-prompt.t',
    't/07-multiple-features.t',
    't/08-prompt-no-load-prereqs.t',
    't/lib/SpecCompliant.pm',
    't/zzz-check-breaks.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
